summaryrefslogtreecommitdiff
path: root/src/tls
diff options
context:
space:
mode:
Diffstat (limited to 'src/tls')
-rw-r--r--src/tls/tls.erl26
-rw-r--r--src/tls/tls_drv.c20
2 files changed, 41 insertions, 5 deletions
diff --git a/src/tls/tls_drv.c b/src/tls/tls_drv.c
index 92f00975..a2d55fdd 100644
--- a/src/tls/tls_drv.c
+++ b/src/tls/tls_drv.c
@@ -1,4 +1,22 @@
-/* $Id$ */
+/*
+ * ejabberd, Copyright (C) 2002-2007 Process-one
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ */
#include <stdio.h>
#include <string.h>
diff --git a/src/tls/tls.erl b/src/tls/tls.erl
index 11f5be1c..5aa554e5 100644
--- a/src/tls/tls.erl
+++ b/src/tls/tls.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : tls.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Interface to openssl
-%%% Created : 24 Jul 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 24 Jul 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(tls).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : tls.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Interface to openssl